@@ -2,9 +2,10 @@
 
 from argparse import Namespace
 
+from homeinfotools.exceptions import SSHConnectionError
 from homeinfotools.logging import syslogger
-from homeinfotools.rpc.exceptions import SSHConnectionError
-from homeinfotools.rpc.functions import completed_process_to_json, execute, ssh
+from homeinfotools.functions import completed_process_to_json, execute
+from homeinfotools.ssh import ssh
 
 
 __all__ = ['runcmd']
